use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/App/perlimports.pm',
    'lib/App/perlimports/Annotations.pm',
    'lib/App/perlimports/CLI.pm',
    'lib/App/perlimports/Document.pm',
    'lib/App/perlimports/ExportInspector.pm',
    'lib/App/perlimports/Include.pm',
    'lib/App/perlimports/Role/Logger.pm',
    'script/dump-perl-exports',
    'script/perlimports',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/Document.t',
    't/ExportInspector/SubExporter.t',
    't/ExportInspector/load.t',
    't/after.t',
    't/annotations.t',
    't/args-in-import.t',
    't/builtin.pl',
    't/carp.t',
    't/cast.t',
    't/cli.t',
    't/config-in-import.pl',
    't/cpan-modules/pithub.t',
    't/cpan-modules/test2-v0.t',
    't/do-block.t',
    't/dump-perl-exports.t',
    't/dupes.t',
    't/english.t',
    't/export-tags.t',
    't/exported-variables.t',
    't/find-bin.t',
    't/fully-qualified.t',
    't/func-in-use.t',
    't/func-in-var.t',
    't/geo-ip.t',
    't/hash-in-regex.t',
    't/hash-key.t',
    't/heredoc.t',
    't/ignored-modules.t',
    't/import-error.t',
    't/interpolation.t',
    't/is-ignored.t',
    't/lib/TestHelper.pm',
    't/lookalike-words.t',
    't/meta.t',
    't/method.t',
    't/module-with-inner-packages.t',
    't/moo.t',
    't/moose-types.t',
    't/moose.t',
    't/moosex-types-moose.t',
    't/nested-quotes.t',
    't/never-exports.t',
    't/original-imports.pl',
    't/padding.t',
    't/perl-imports.t',
    't/perl.t',
    't/pragma.t',
    't/preserve-spaces.t',
    't/quoted-var.t',
    't/re-export-via-sub-exporter.t',
    't/regex-replacement.t',
    't/require.t',
    't/script-with-inner-packages.t',
    't/signatures.pl',
    't/skip-all.t',
    't/socket.t',
    't/switches-in-import.t',
    't/symbol-as-method-call.t',
    't/symbol-in-export.t',
    't/test-most.t',
    't/typeglob.t',
    't/use-and-require.t',
    't/var-in-hash-key.pl',
    't/var-in-regex.t',
    't/variable.t',
    't/with-version.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
